Class: Aws::Wickr::Types::BatchDeleteUserRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique identifier for this request to ensure idempotency. If you retry a request with the same client token, the service will return the same response without attempting to delete users again.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


208
209
210
211
212
213
214
# File 'lib/aws-sdk-wickr/types.rb', line 208

class BatchDeleteUserRequest < Struct.new(
  :network_id,
  :user_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_idString

The ID of the Wickr network from which users will be deleted.

Returns:

  • (String)


208
209
210
211
212
213
214
# File 'lib/aws-sdk-wickr/types.rb', line 208

class BatchDeleteUserRequest < Struct.new(
  :network_id,
  :user_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#user_idsArray<String>

A list of user IDs identifying the users to be deleted from the network. Maximum 50 users per batch request.

Returns:

  • (Array<String>)


208
209
210
211
212
213
214
# File 'lib/aws-sdk-wickr/types.rb', line 208

class BatchDeleteUserRequest < Struct.new(
  :network_id,
  :user_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end