Class: Aws::Wickr::Types::BatchReinviteUserRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique identifier for this request to ensure idempotency.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


350
351
352
353
354
355
356
# File 'lib/aws-sdk-wickr/types.rb', line 350

class BatchReinviteUserRequest < Struct.new(
  :network_id,
  :user_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_idString

The ID of the Wickr network where users will be reinvited.

Returns:

  • (String)


350
351
352
353
354
355
356
# File 'lib/aws-sdk-wickr/types.rb', line 350

class BatchReinviteUserRequest < Struct.new(
  :network_id,
  :user_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#user_idsArray<String>

A list of user IDs identifying the users to be reinvited to the network. Maximum 50 users per batch request.

Returns:

  • (Array<String>)


350
351
352
353
354
355
356
# File 'lib/aws-sdk-wickr/types.rb', line 350

class BatchReinviteUserRequest < Struct.new(
  :network_id,
  :user_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end