Class: Aws::Wickr::Types::BatchResetDevicesForUserRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_idsArray<String>

A list of application IDs identifying the specific devices to be reset for the user. Maximum 50 devices per batch request.

Returns:

  • (Array<String>)


405
406
407
408
409
410
411
412
# File 'lib/aws-sdk-wickr/types.rb', line 405

class BatchResetDevicesForUserRequest < Struct.new(
  :network_id,
  :user_id,
  :app_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique identifier for this request to ensure idempotency.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


405
406
407
408
409
410
411
412
# File 'lib/aws-sdk-wickr/types.rb', line 405

class BatchResetDevicesForUserRequest < Struct.new(
  :network_id,
  :user_id,
  :app_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_idString

The ID of the Wickr network containing the user whose devices will be reset.

Returns:

  • (String)


405
406
407
408
409
410
411
412
# File 'lib/aws-sdk-wickr/types.rb', line 405

class BatchResetDevicesForUserRequest < Struct.new(
  :network_id,
  :user_id,
  :app_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

The ID of the user whose devices will be reset.

Returns:

  • (String)


405
406
407
408
409
410
411
412
# File 'lib/aws-sdk-wickr/types.rb', line 405

class BatchResetDevicesForUserRequest < Struct.new(
  :network_id,
  :user_id,
  :app_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end