Class: Aws::Wickr::Types::BatchResetDevicesForUserResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failedArray<Types::BatchDeviceErrorResponseItem>

A list of device reset attempts that failed, including error details explaining why each device could not be reset.



430
431
432
433
434
435
436
# File 'lib/aws-sdk-wickr/types.rb', line 430

class BatchResetDevicesForUserResponse < Struct.new(
  :message,
  :successful,
  :failed)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message indicating the overall result of the batch device reset operation.

Returns:

  • (String)


430
431
432
433
434
435
436
# File 'lib/aws-sdk-wickr/types.rb', line 430

class BatchResetDevicesForUserResponse < Struct.new(
  :message,
  :successful,
  :failed)
  SENSITIVE = []
  include Aws::Structure
end

#successfulArray<Types::BatchDeviceSuccessResponseItem>

A list of application IDs that were successfully reset.



430
431
432
433
434
435
436
# File 'lib/aws-sdk-wickr/types.rb', line 430

class BatchResetDevicesForUserResponse < Struct.new(
  :message,
  :successful,
  :failed)
  SENSITIVE = []
  include Aws::Structure
end