Class: Aws::Wickr::Types::CreateDataRetentionBotChallengeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::CreateDataRetentionBotChallengeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:challenge]
Instance Attribute Summary collapse
-
#challenge ⇒ String
The newly generated challenge password for the data retention bot.
Instance Attribute Details
#challenge ⇒ String
The newly generated challenge password for the data retention bot.
822 823 824 825 826 |
# File 'lib/aws-sdk-wickr/types.rb', line 822 class CreateDataRetentionBotChallengeResponse < Struct.new( :challenge) SENSITIVE = [:challenge] include Aws::Structure end |