Class: Aws::Wickr::Types::DeleteNetworkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::DeleteNetworkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique identifier for this request to ensure idempotency.
-
#network_id ⇒ String
The ID of the Wickr network to delete.
Instance Attribute Details
#client_token ⇒ String
A unique identifier for this request to ensure idempotency. If you retry a request with the same client token, the service will return the same response without attempting to delete the network again.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
991 992 993 994 995 996 |
# File 'lib/aws-sdk-wickr/types.rb', line 991 class DeleteNetworkRequest < Struct.new( :network_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#network_id ⇒ String
The ID of the Wickr network to delete.
991 992 993 994 995 996 |
# File 'lib/aws-sdk-wickr/types.rb', line 991 class DeleteNetworkRequest < Struct.new( :network_id, :client_token) SENSITIVE = [] include Aws::Structure end |