Class: Aws::Wickr::Types::DeleteSecurityGroupResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#group_idString

The ID of the security group that was deleted.

Returns:

  • (String)


1044
1045
1046
1047
1048
1049
1050
# File 'lib/aws-sdk-wickr/types.rb', line 1044

class DeleteSecurityGroupResponse < Struct.new(
  :message,
  :network_id,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message indicating the result of the security group deletion operation.

Returns:

  • (String)


1044
1045
1046
1047
1048
1049
1050
# File 'lib/aws-sdk-wickr/types.rb', line 1044

class DeleteSecurityGroupResponse < Struct.new(
  :message,
  :network_id,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_idString

The ID of the network from which the security group was deleted.

Returns:

  • (String)


1044
1045
1046
1047
1048
1049
1050
# File 'lib/aws-sdk-wickr/types.rb', line 1044

class DeleteSecurityGroupResponse < Struct.new(
  :message,
  :network_id,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end