Class: Aws::Wickr::Types::GetBotsCountResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::GetBotsCountResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active ⇒ Integer
The number of bots with active status.
-
#pending ⇒ Integer
The number of bots with pending status (invited but not yet activated).
-
#total ⇒ Integer
The total number of bots in the network (active and pending).
Instance Attribute Details
#active ⇒ Integer
The number of bots with active status.
1224 1225 1226 1227 1228 1229 1230 |
# File 'lib/aws-sdk-wickr/types.rb', line 1224 class GetBotsCountResponse < Struct.new( :pending, :active, :total) SENSITIVE = [] include Aws::Structure end |
#pending ⇒ Integer
The number of bots with pending status (invited but not yet activated).
1224 1225 1226 1227 1228 1229 1230 |
# File 'lib/aws-sdk-wickr/types.rb', line 1224 class GetBotsCountResponse < Struct.new( :pending, :active, :total) SENSITIVE = [] include Aws::Structure end |
#total ⇒ Integer
The total number of bots in the network (active and pending).
1224 1225 1226 1227 1228 1229 1230 |
# File 'lib/aws-sdk-wickr/types.rb', line 1224 class GetBotsCountResponse < Struct.new( :pending, :active, :total) SENSITIVE = [] include Aws::Structure end |