Class: Aws::Wickr::Types::GetDataRetentionBotResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::GetDataRetentionBotResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_exists ⇒ Boolean
Indicates whether a data retention bot exists in the network.
-
#bot_name ⇒ String
The name of the data retention bot.
-
#is_bot_active ⇒ Boolean
Indicates whether the data retention bot is active and operational.
-
#is_data_retention_bot_registered ⇒ Boolean
Indicates whether the data retention bot has been registered with the network.
-
#is_data_retention_service_enabled ⇒ Boolean
Indicates whether the data retention service is enabled for the network.
-
#is_pubkey_msg_acked ⇒ Boolean
Indicates whether the public key message has been acknowledged by the bot.
Instance Attribute Details
#bot_exists ⇒ Boolean
Indicates whether a data retention bot exists in the network.
1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 |
# File 'lib/aws-sdk-wickr/types.rb', line 1273 class GetDataRetentionBotResponse < Struct.new( :bot_name, :bot_exists, :is_bot_active, :is_data_retention_bot_registered, :is_data_retention_service_enabled, :is_pubkey_msg_acked) SENSITIVE = [] include Aws::Structure end |
#bot_name ⇒ String
The name of the data retention bot.
1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 |
# File 'lib/aws-sdk-wickr/types.rb', line 1273 class GetDataRetentionBotResponse < Struct.new( :bot_name, :bot_exists, :is_bot_active, :is_data_retention_bot_registered, :is_data_retention_service_enabled, :is_pubkey_msg_acked) SENSITIVE = [] include Aws::Structure end |
#is_bot_active ⇒ Boolean
Indicates whether the data retention bot is active and operational.
1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 |
# File 'lib/aws-sdk-wickr/types.rb', line 1273 class GetDataRetentionBotResponse < Struct.new( :bot_name, :bot_exists, :is_bot_active, :is_data_retention_bot_registered, :is_data_retention_service_enabled, :is_pubkey_msg_acked) SENSITIVE = [] include Aws::Structure end |
#is_data_retention_bot_registered ⇒ Boolean
Indicates whether the data retention bot has been registered with the network.
1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 |
# File 'lib/aws-sdk-wickr/types.rb', line 1273 class GetDataRetentionBotResponse < Struct.new( :bot_name, :bot_exists, :is_bot_active, :is_data_retention_bot_registered, :is_data_retention_service_enabled, :is_pubkey_msg_acked) SENSITIVE = [] include Aws::Structure end |
#is_data_retention_service_enabled ⇒ Boolean
Indicates whether the data retention service is enabled for the network.
1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 |
# File 'lib/aws-sdk-wickr/types.rb', line 1273 class GetDataRetentionBotResponse < Struct.new( :bot_name, :bot_exists, :is_bot_active, :is_data_retention_bot_registered, :is_data_retention_service_enabled, :is_pubkey_msg_acked) SENSITIVE = [] include Aws::Structure end |
#is_pubkey_msg_acked ⇒ Boolean
Indicates whether the public key message has been acknowledged by the bot.
1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 |
# File 'lib/aws-sdk-wickr/types.rb', line 1273 class GetDataRetentionBotResponse < Struct.new( :bot_name, :bot_exists, :is_bot_active, :is_data_retention_bot_registered, :is_data_retention_service_enabled, :is_pubkey_msg_acked) SENSITIVE = [] include Aws::Structure end |