Class: Aws::Wickr::Types::GetGuestUserHistoryCountRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::GetGuestUserHistoryCountRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_id ⇒ String
The ID of the Wickr network for which to retrieve guest user history.
Instance Attribute Details
#network_id ⇒ String
The ID of the Wickr network for which to retrieve guest user history.
1258 1259 1260 1261 1262 |
# File 'lib/aws-sdk-wickr/types.rb', line 1258 class GetGuestUserHistoryCountRequest < Struct.new( :network_id) SENSITIVE = [] include Aws::Structure end |