Class: Aws::Wickr::Types::GetGuestUserHistoryCountResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::GetGuestUserHistoryCountResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#history ⇒ Array<Types::GuestUserHistoryCount>
A list of historical guest user counts, organized by month and billing period.
Instance Attribute Details
#history ⇒ Array<Types::GuestUserHistoryCount>
A list of historical guest user counts, organized by month and billing period.
1271 1272 1273 1274 1275 |
# File 'lib/aws-sdk-wickr/types.rb', line 1271 class GetGuestUserHistoryCountResponse < Struct.new( :history) SENSITIVE = [] include Aws::Structure end |