Class: Aws::Wickr::Types::GetNetworkSettingsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::GetNetworkSettingsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#settings ⇒ Array<Types::Setting>
A list of network settings, where each setting includes a name, value, and type.
Instance Attribute Details
#settings ⇒ Array<Types::Setting>
A list of network settings, where each setting includes a name, value, and type.
1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-wickr/types.rb', line 1398 class GetNetworkSettingsResponse < Struct.new( :settings) SENSITIVE = [] include Aws::Structure end |