Class: Aws::Wickr::Types::GetUserResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:first_name, :last_name]

Instance Attribute Summary collapse

Instance Attribute Details

#first_nameString

The first name of the user.

Returns:

  • (String)


1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-wickr/types.rb', line 1627

class GetUserResponse < Struct.new(
  :user_id,
  :first_name,
  :last_name,
  :username,
  :is_admin,
  :suspended,
  :status,
  :last_activity,
  :last_login,
  :security_group_ids)
  SENSITIVE = [:first_name, :last_name]
  include Aws::Structure
end

#is_adminBoolean

Indicates whether the user has administrator privileges in the network.

Returns:

  • (Boolean)


1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-wickr/types.rb', line 1627

class GetUserResponse < Struct.new(
  :user_id,
  :first_name,
  :last_name,
  :username,
  :is_admin,
  :suspended,
  :status,
  :last_activity,
  :last_login,
  :security_group_ids)
  SENSITIVE = [:first_name, :last_name]
  include Aws::Structure
end

#last_activityInteger

The timestamp of the user’s last activity in the network, specified in epoch seconds.

Returns:

  • (Integer)


1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-wickr/types.rb', line 1627

class GetUserResponse < Struct.new(
  :user_id,
  :first_name,
  :last_name,
  :username,
  :is_admin,
  :suspended,
  :status,
  :last_activity,
  :last_login,
  :security_group_ids)
  SENSITIVE = [:first_name, :last_name]
  include Aws::Structure
end

#last_loginInteger

The timestamp of the user’s last login to the network, specified in epoch seconds.

Returns:

  • (Integer)


1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-wickr/types.rb', line 1627

class GetUserResponse < Struct.new(
  :user_id,
  :first_name,
  :last_name,
  :username,
  :is_admin,
  :suspended,
  :status,
  :last_activity,
  :last_login,
  :security_group_ids)
  SENSITIVE = [:first_name, :last_name]
  include Aws::Structure
end

#last_nameString

The last name of the user.

Returns:

  • (String)


1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-wickr/types.rb', line 1627

class GetUserResponse < Struct.new(
  :user_id,
  :first_name,
  :last_name,
  :username,
  :is_admin,
  :suspended,
  :status,
  :last_activity,
  :last_login,
  :security_group_ids)
  SENSITIVE = [:first_name, :last_name]
  include Aws::Structure
end

#security_group_idsArray<String>

A list of security group IDs to which the user belongs.

Returns:

  • (Array<String>)


1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-wickr/types.rb', line 1627

class GetUserResponse < Struct.new(
  :user_id,
  :first_name,
  :last_name,
  :username,
  :is_admin,
  :suspended,
  :status,
  :last_activity,
  :last_login,
  :security_group_ids)
  SENSITIVE = [:first_name, :last_name]
  include Aws::Structure
end

#statusInteger

The current status of the user (1 for pending, 2 for active).

Returns:

  • (Integer)


1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-wickr/types.rb', line 1627

class GetUserResponse < Struct.new(
  :user_id,
  :first_name,
  :last_name,
  :username,
  :is_admin,
  :suspended,
  :status,
  :last_activity,
  :last_login,
  :security_group_ids)
  SENSITIVE = [:first_name, :last_name]
  include Aws::Structure
end

#suspendedBoolean

Indicates whether the user is currently suspended.

Returns:

  • (Boolean)


1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-wickr/types.rb', line 1627

class GetUserResponse < Struct.new(
  :user_id,
  :first_name,
  :last_name,
  :username,
  :is_admin,
  :suspended,
  :status,
  :last_activity,
  :last_login,
  :security_group_ids)
  SENSITIVE = [:first_name, :last_name]
  include Aws::Structure
end

#user_idString

The unique identifier of the user.

Returns:

  • (String)


1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-wickr/types.rb', line 1627

class GetUserResponse < Struct.new(
  :user_id,
  :first_name,
  :last_name,
  :username,
  :is_admin,
  :suspended,
  :status,
  :last_activity,
  :last_login,
  :security_group_ids)
  SENSITIVE = [:first_name, :last_name]
  include Aws::Structure
end

#usernameString

The email address or username of the user.

Returns:

  • (String)


1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-wickr/types.rb', line 1627

class GetUserResponse < Struct.new(
  :user_id,
  :first_name,
  :last_name,
  :username,
  :is_admin,
  :suspended,
  :status,
  :last_activity,
  :last_login,
  :security_group_ids)
  SENSITIVE = [:first_name, :last_name]
  include Aws::Structure
end