Class: Aws::Wickr::Types::GetUsersCountRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::GetUsersCountRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_id ⇒ String
The ID of the Wickr network for which to retrieve user counts.
Instance Attribute Details
#network_id ⇒ String
The ID of the Wickr network for which to retrieve user counts.
1648 1649 1650 1651 1652 |
# File 'lib/aws-sdk-wickr/types.rb', line 1648 class GetUsersCountRequest < Struct.new( :network_id) SENSITIVE = [] include Aws::Structure end |