Class: Aws::Wickr::Types::GuestUser

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Represents a guest user who has accessed the network from a federated Wickr network.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billing_periodString

The billing period when this guest user accessed the network (e.g., ‘2024-01’).

Returns:

  • (String)


1707
1708
1709
1710
1711
1712
1713
# File 'lib/aws-sdk-wickr/types.rb', line 1707

class GuestUser < Struct.new(
  :billing_period,
  :username,
  :username_hash)
  SENSITIVE = []
  include Aws::Structure
end

#usernameString

The username of the guest user.

Returns:

  • (String)


1707
1708
1709
1710
1711
1712
1713
# File 'lib/aws-sdk-wickr/types.rb', line 1707

class GuestUser < Struct.new(
  :billing_period,
  :username,
  :username_hash)
  SENSITIVE = []
  include Aws::Structure
end

#username_hashString

The unique username hash identifier for the guest user.

Returns:

  • (String)


1707
1708
1709
1710
1711
1712
1713
# File 'lib/aws-sdk-wickr/types.rb', line 1707

class GuestUser < Struct.new(
  :billing_period,
  :username,
  :username_hash)
  SENSITIVE = []
  include Aws::Structure
end