Class: Aws::Wickr::Types::GuestUserHistoryCount

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Contains the count of guest users for a specific billing period, used for tracking historical guest user activity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#countString

The number of guest users who have communicated with your Wickr network during this billing period.

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
# File 'lib/aws-sdk-wickr/types.rb', line 1697

class GuestUserHistoryCount < Struct.new(
  :month,
  :count)
  SENSITIVE = []
  include Aws::Structure
end

#monthString

The month and billing period in YYYY_MM format (e.g., ‘2024_01’).

Returns:

  • (String)


1697
1698
1699
1700
1701
1702
# File 'lib/aws-sdk-wickr/types.rb', line 1697

class GuestUserHistoryCount < Struct.new(
  :month,
  :count)
  SENSITIVE = []
  include Aws::Structure
end