Class: Aws::Wickr::Types::ListBlockedGuestUsersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#adminString

Filter results to only include blocked guest users that were blocked by this administrator.

Returns:

  • (String)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
# File 'lib/aws-sdk-wickr/types.rb', line 1790

class ListBlockedGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :admin,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of blocked guest users to return in a single page. Valid range is 1-100. Default is 10.

Returns:

  • (Integer)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
# File 'lib/aws-sdk-wickr/types.rb', line 1790

class ListBlockedGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :admin,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_idString

The ID of the Wickr network from which to list blocked guest users.

Returns:

  • (String)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
# File 'lib/aws-sdk-wickr/types.rb', line 1790

class ListBlockedGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :admin,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for retrieving the next page of results. This is returned from a previous request when there are more results available.

Returns:

  • (String)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
# File 'lib/aws-sdk-wickr/types.rb', line 1790

class ListBlockedGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :admin,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_directionString

The direction to sort results. Valid values are 'ASC' (ascending) or 'DESC' (descending). Default is 'DESC'.

Returns:

  • (String)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
# File 'lib/aws-sdk-wickr/types.rb', line 1790

class ListBlockedGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :admin,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_fieldsString

The field to sort blocked guest users by. Accepted values include 'username', 'admin', and 'modified'.

Returns:

  • (String)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
# File 'lib/aws-sdk-wickr/types.rb', line 1790

class ListBlockedGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :admin,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#usernameString

Filter results to only include blocked guest users with usernames matching this value.

Returns:

  • (String)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
# File 'lib/aws-sdk-wickr/types.rb', line 1790

class ListBlockedGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :admin,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end