Class: Aws::Wickr::Types::ListBlockedGuestUsersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#blocklistArray<Types::BlockedGuestUser>

A list of blocked guest user objects within the current page.

Returns:



1813
1814
1815
1816
1817
1818
# File 'lib/aws-sdk-wickr/types.rb', line 1813

class ListBlockedGuestUsersResponse < Struct.new(
  :next_token,
  :blocklist)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use for retrieving the next page of results. If this is not present, there are no more results.

Returns:

  • (String)


1813
1814
1815
1816
1817
1818
# File 'lib/aws-sdk-wickr/types.rb', line 1813

class ListBlockedGuestUsersResponse < Struct.new(
  :next_token,
  :blocklist)
  SENSITIVE = []
  include Aws::Structure
end