Class: Aws::Wickr::Types::ListBotsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#display_nameString

Filter results to only include bots with display names matching this value.

Returns:



1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-wickr/types.rb', line 1867

class ListBotsRequest < Struct.new(
  :network_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction,
  :display_name,
  :username,
  :status,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end

#group_idString

Filter results to only include bots belonging to this security group.

Returns:



1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-wickr/types.rb', line 1867

class ListBotsRequest < Struct.new(
  :network_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction,
  :display_name,
  :username,
  :status,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of bots to return in a single page. Valid range is 1-100. Default is 10.

Returns:



1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-wickr/types.rb', line 1867

class ListBotsRequest < Struct.new(
  :network_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction,
  :display_name,
  :username,
  :status,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_idString

The ID of the Wickr network from which to list bots.

Returns:



1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-wickr/types.rb', line 1867

class ListBotsRequest < Struct.new(
  :network_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction,
  :display_name,
  :username,
  :status,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for retrieving the next page of results. This is returned from a previous request when there are more results available.

Returns:



1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-wickr/types.rb', line 1867

class ListBotsRequest < Struct.new(
  :network_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction,
  :display_name,
  :username,
  :status,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end

#sort_directionString

The direction to sort results. Valid values are 'ASC' (ascending) or 'DESC' (descending). Default is 'DESC'.

Returns:



1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-wickr/types.rb', line 1867

class ListBotsRequest < Struct.new(
  :network_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction,
  :display_name,
  :username,
  :status,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end

#sort_fieldsString

The fields to sort bots by. Multiple fields can be specified by separating them with '+'. Accepted values include 'username', 'firstName', 'displayName', 'status', and 'groupId'.

Returns:



1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-wickr/types.rb', line 1867

class ListBotsRequest < Struct.new(
  :network_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction,
  :display_name,
  :username,
  :status,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

Filter results to only include bots with this status (1 for pending, 2 for active).

Returns:



1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-wickr/types.rb', line 1867

class ListBotsRequest < Struct.new(
  :network_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction,
  :display_name,
  :username,
  :status,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end

#usernameString

Filter results to only include bots with usernames matching this value.

Returns:



1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/aws-sdk-wickr/types.rb', line 1867

class ListBotsRequest < Struct.new(
  :network_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction,
  :display_name,
  :username,
  :status,
  :group_id)
  SENSITIVE = []
  include Aws::Structure
end