Class: Aws::Wickr::Types::ListBotsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#botsArray<Types::Bot>

A list of bot objects matching the specified filters and within the current page.

Returns:



1893
1894
1895
1896
1897
1898
# File 'lib/aws-sdk-wickr/types.rb', line 1893

class ListBotsResponse < Struct.new(
  :bots,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use for retrieving the next page of results. If this is not present, there are no more results.

Returns:

  • (String)


1893
1894
1895
1896
1897
1898
# File 'lib/aws-sdk-wickr/types.rb', line 1893

class ListBotsResponse < Struct.new(
  :bots,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end