Class: Aws::Wickr::Types::ListGuestUsersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billing_periodString

Filter results to only include guest users from this billing period (e.g., '2024-01').

Returns:

  • (String)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
# File 'lib/aws-sdk-wickr/types.rb', line 1997

class ListGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :billing_period,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of guest users to return in a single page. Valid range is 1-100. Default is 10.

Returns:

  • (Integer)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
# File 'lib/aws-sdk-wickr/types.rb', line 1997

class ListGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :billing_period,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#network_idString

The ID of the Wickr network from which to list guest users.

Returns:

  • (String)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
# File 'lib/aws-sdk-wickr/types.rb', line 1997

class ListGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :billing_period,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for retrieving the next page of results. This is returned from a previous request when there are more results available.

Returns:

  • (String)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
# File 'lib/aws-sdk-wickr/types.rb', line 1997

class ListGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :billing_period,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_directionString

The direction to sort results. Valid values are 'ASC' (ascending) or 'DESC' (descending). Default is 'DESC'.

Returns:

  • (String)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
# File 'lib/aws-sdk-wickr/types.rb', line 1997

class ListGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :billing_period,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_fieldsString

The field to sort guest users by. Accepted values include 'username' and 'billingPeriod'.

Returns:

  • (String)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
# File 'lib/aws-sdk-wickr/types.rb', line 1997

class ListGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :billing_period,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#usernameString

Filter results to only include guest users with usernames matching this value.

Returns:

  • (String)


1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
# File 'lib/aws-sdk-wickr/types.rb', line 1997

class ListGuestUsersRequest < Struct.new(
  :network_id,
  :max_results,
  :sort_direction,
  :sort_fields,
  :username,
  :billing_period,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end