Class: Aws::Wickr::Types::ListGuestUsersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#guestlistArray<Types::GuestUser>

A list of guest user objects within the current page.

Returns:



2020
2021
2022
2023
2024
2025
# File 'lib/aws-sdk-wickr/types.rb', line 2020

class ListGuestUsersResponse < Struct.new(
  :next_token,
  :guestlist)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use for retrieving the next page of results. If this is not present, there are no more results.

Returns:

  • (String)


2020
2021
2022
2023
2024
2025
# File 'lib/aws-sdk-wickr/types.rb', line 2020

class ListGuestUsersResponse < Struct.new(
  :next_token,
  :guestlist)
  SENSITIVE = []
  include Aws::Structure
end