Class: Aws::Wickr::Types::ListSecurityGroupUsersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#group_idString

The unique identifier of the security group whose users will be listed.

Returns:

  • (String)


2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
# File 'lib/aws-sdk-wickr/types.rb', line 2108

class ListSecurityGroupUsersRequest < Struct.new(
  :network_id,
  :group_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of users to return in a single page. Valid range is 1-100. Default is 10.

Returns:

  • (Integer)


2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
# File 'lib/aws-sdk-wickr/types.rb', line 2108

class ListSecurityGroupUsersRequest < Struct.new(
  :network_id,
  :group_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction)
  SENSITIVE = []
  include Aws::Structure
end

#network_idString

The ID of the Wickr network containing the security group.

Returns:

  • (String)


2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
# File 'lib/aws-sdk-wickr/types.rb', line 2108

class ListSecurityGroupUsersRequest < Struct.new(
  :network_id,
  :group_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for retrieving the next page of results. This is returned from a previous request when there are more results available.

Returns:

  • (String)


2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
# File 'lib/aws-sdk-wickr/types.rb', line 2108

class ListSecurityGroupUsersRequest < Struct.new(
  :network_id,
  :group_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction)
  SENSITIVE = []
  include Aws::Structure
end

#sort_directionString

The direction to sort results. Valid values are 'ASC' (ascending) or 'DESC' (descending). Default is 'DESC'.

Returns:

  • (String)


2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
# File 'lib/aws-sdk-wickr/types.rb', line 2108

class ListSecurityGroupUsersRequest < Struct.new(
  :network_id,
  :group_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction)
  SENSITIVE = []
  include Aws::Structure
end

#sort_fieldsString

The field to sort users by. Multiple fields can be specified by separating them with '+'. Accepted values include 'username', 'firstName', and 'lastName'.

Returns:

  • (String)


2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
# File 'lib/aws-sdk-wickr/types.rb', line 2108

class ListSecurityGroupUsersRequest < Struct.new(
  :network_id,
  :group_id,
  :next_token,
  :max_results,
  :sort_fields,
  :sort_direction)
  SENSITIVE = []
  include Aws::Structure
end