Class: Aws::Wickr::Types::ListSecurityGroupUsersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to use for retrieving the next page of results. If this is not present, there are no more results.

Returns:

  • (String)


2131
2132
2133
2134
2135
2136
# File 'lib/aws-sdk-wickr/types.rb', line 2131

class ListSecurityGroupUsersResponse < Struct.new(
  :users,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#usersArray<Types::User>

A list of user objects belonging to the security group within the current page.

Returns:



2131
2132
2133
2134
2135
2136
# File 'lib/aws-sdk-wickr/types.rb', line 2131

class ListSecurityGroupUsersResponse < Struct.new(
  :users,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end