Class: Aws::Wickr::Types::ListSecurityGroupsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to use for retrieving the next page of results. If this is not present, there are no more results.

Returns:

  • (String)


2185
2186
2187
2188
2189
2190
# File 'lib/aws-sdk-wickr/types.rb', line 2185

class ListSecurityGroupsResponse < Struct.new(
  :security_groups,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#security_groupsArray<Types::SecurityGroup>

A list of security group objects in the current page.

Returns:



2185
2186
2187
2188
2189
2190
# File 'lib/aws-sdk-wickr/types.rb', line 2185

class ListSecurityGroupsResponse < Struct.new(
  :security_groups,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end