Class: Aws::Wickr::Types::NetworkSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Contains network-level configuration settings that apply to all users and security groups within a Wickr network.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

Consent popup configuration for the network, displayed to users on login.



2371
2372
2373
2374
2375
2376
2377
2378
2379
# File 'lib/aws-sdk-wickr/types.rb', line 2371

class NetworkSettings < Struct.new(
  :enable_client_metrics,
  :read_receipt_config,
  :data_retention,
  :enable_trusted_data_format,
  :consent_popup)
  SENSITIVE = []
  include Aws::Structure
end

#data_retentionBoolean

Indicates whether the data retention feature is enabled for the network. When true, messages are captured by the data retention bot for compliance and archiving purposes.

Returns:

  • (Boolean)


2371
2372
2373
2374
2375
2376
2377
2378
2379
# File 'lib/aws-sdk-wickr/types.rb', line 2371

class NetworkSettings < Struct.new(
  :enable_client_metrics,
  :read_receipt_config,
  :data_retention,
  :enable_trusted_data_format,
  :consent_popup)
  SENSITIVE = []
  include Aws::Structure
end

#enable_client_metricsBoolean

Allows Wickr clients to send anonymized performance and usage metrics to the Wickr backend server for service improvement and troubleshooting.

Returns:

  • (Boolean)


2371
2372
2373
2374
2375
2376
2377
2378
2379
# File 'lib/aws-sdk-wickr/types.rb', line 2371

class NetworkSettings < Struct.new(
  :enable_client_metrics,
  :read_receipt_config,
  :data_retention,
  :enable_trusted_data_format,
  :consent_popup)
  SENSITIVE = []
  include Aws::Structure
end

#enable_trusted_data_formatBoolean

Configuration for OpenTDF integration at the network level, enforcing ABAC decision making when operating in TDF enabled rooms.

Returns:

  • (Boolean)


2371
2372
2373
2374
2375
2376
2377
2378
2379
# File 'lib/aws-sdk-wickr/types.rb', line 2371

class NetworkSettings < Struct.new(
  :enable_client_metrics,
  :read_receipt_config,
  :data_retention,
  :enable_trusted_data_format,
  :consent_popup)
  SENSITIVE = []
  include Aws::Structure
end

#read_receipt_configTypes::ReadReceiptConfig

Configuration for read receipts at the network level, controlling the default behavior for whether senders can see when their messages have been read.



2371
2372
2373
2374
2375
2376
2377
2378
2379
# File 'lib/aws-sdk-wickr/types.rb', line 2371

class NetworkSettings < Struct.new(
  :enable_client_metrics,
  :read_receipt_config,
  :data_retention,
  :enable_trusted_data_format,
  :consent_popup)
  SENSITIVE = []
  include Aws::Structure
end