Class: Aws::Wickr::Types::PasswordRequirements

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Defines password complexity requirements for users in a security group, including minimum length and character type requirements.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lowercaseInteger

The minimum number of lowercase letters required in passwords.

Returns:

  • (Integer)


2520
2521
2522
2523
2524
2525
2526
2527
2528
# File 'lib/aws-sdk-wickr/types.rb', line 2520

class PasswordRequirements < Struct.new(
  :lowercase,
  :min_length,
  :numbers,
  :symbols,
  :uppercase)
  SENSITIVE = []
  include Aws::Structure
end

#min_lengthInteger

The minimum password length in characters.

Returns:

  • (Integer)


2520
2521
2522
2523
2524
2525
2526
2527
2528
# File 'lib/aws-sdk-wickr/types.rb', line 2520

class PasswordRequirements < Struct.new(
  :lowercase,
  :min_length,
  :numbers,
  :symbols,
  :uppercase)
  SENSITIVE = []
  include Aws::Structure
end

#numbersInteger

The minimum number of numeric characters required in passwords.

Returns:

  • (Integer)


2520
2521
2522
2523
2524
2525
2526
2527
2528
# File 'lib/aws-sdk-wickr/types.rb', line 2520

class PasswordRequirements < Struct.new(
  :lowercase,
  :min_length,
  :numbers,
  :symbols,
  :uppercase)
  SENSITIVE = []
  include Aws::Structure
end

#symbolsInteger

The minimum number of special symbol characters required in passwords.

Returns:

  • (Integer)


2520
2521
2522
2523
2524
2525
2526
2527
2528
# File 'lib/aws-sdk-wickr/types.rb', line 2520

class PasswordRequirements < Struct.new(
  :lowercase,
  :min_length,
  :numbers,
  :symbols,
  :uppercase)
  SENSITIVE = []
  include Aws::Structure
end

#uppercaseInteger

The minimum number of uppercase letters required in passwords.

Returns:

  • (Integer)


2520
2521
2522
2523
2524
2525
2526
2527
2528
# File 'lib/aws-sdk-wickr/types.rb', line 2520

class PasswordRequirements < Struct.new(
  :lowercase,
  :min_length,
  :numbers,
  :symbols,
  :uppercase)
  SENSITIVE = []
  include Aws::Structure
end