Class: Aws::Wickr::Types::PermittedWickrEnterpriseNetwork

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Identifies a Wickr enterprise network that is permitted for global federation, allowing users to communicate with members of the specified network.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domainString

The domain identifier for the permitted Wickr enterprise network.

Returns:

  • (String)


2544
2545
2546
2547
2548
2549
# File 'lib/aws-sdk-wickr/types.rb', line 2544

class PermittedWickrEnterpriseNetwork < Struct.new(
  :domain,
  :network_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_idString

The network ID of the permitted Wickr enterprise network.

Returns:

  • (String)


2544
2545
2546
2547
2548
2549
# File 'lib/aws-sdk-wickr/types.rb', line 2544

class PermittedWickrEnterpriseNetwork < Struct.new(
  :domain,
  :network_id)
  SENSITIVE = []
  include Aws::Structure
end