Class: Aws::Wickr::Types::RateLimitError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

The request was throttled because too many requests were sent in a short period of time. Wait a moment and retry the request. Consider implementing exponential backoff in your application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

A message indicating that the rate limit was exceeded and suggesting when to retry.

Returns:

  • (String)


2562
2563
2564
2565
2566
# File 'lib/aws-sdk-wickr/types.rb', line 2562

class RateLimitError < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end