Class: Aws::Wickr::Types::ResourceNotFoundError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::ResourceNotFoundError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
The requested resource could not be found. This error occurs when you try to access or modify a network, user, bot, security group, or other resource that doesn’t exist or has been deleted.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A message identifying which resource was not found.
Instance Attribute Details
#message ⇒ String
A message identifying which resource was not found.
2952 2953 2954 2955 2956 |
# File 'lib/aws-sdk-wickr/types.rb', line 2952 class ResourceNotFoundError < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |