Class: Aws::Wickr::Types::UnauthorizedError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

The request was not authenticated or the authentication credentials were invalid. This error occurs when the request lacks valid authentication credentials or the credentials have expired.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

A message explaining why the authentication failed.

Returns:



3380
3381
3382
3383
3384
# File 'lib/aws-sdk-wickr/types.rb', line 3380

class UnauthorizedError < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end