Class: Aws::Wickr::Types::UpdateBotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::UpdateBotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:challenge]
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The unique identifier of the bot to update.
-
#challenge ⇒ String
The new password for the bot account.
-
#display_name ⇒ String
The new display name for the bot.
-
#group_id ⇒ String
The ID of the new security group to assign the bot to.
-
#network_id ⇒ String
The ID of the Wickr network containing the bot to update.
-
#suspend ⇒ Boolean
Set to true to suspend the bot or false to unsuspend it.
Instance Attribute Details
#bot_id ⇒ String
The unique identifier of the bot to update.
3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 |
# File 'lib/aws-sdk-wickr/types.rb', line 3413 class UpdateBotRequest < Struct.new( :network_id, :bot_id, :display_name, :group_id, :challenge, :suspend) SENSITIVE = [:challenge] include Aws::Structure end |
#challenge ⇒ String
The new password for the bot account.
3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 |
# File 'lib/aws-sdk-wickr/types.rb', line 3413 class UpdateBotRequest < Struct.new( :network_id, :bot_id, :display_name, :group_id, :challenge, :suspend) SENSITIVE = [:challenge] include Aws::Structure end |
#display_name ⇒ String
The new display name for the bot.
3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 |
# File 'lib/aws-sdk-wickr/types.rb', line 3413 class UpdateBotRequest < Struct.new( :network_id, :bot_id, :display_name, :group_id, :challenge, :suspend) SENSITIVE = [:challenge] include Aws::Structure end |
#group_id ⇒ String
The ID of the new security group to assign the bot to.
3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 |
# File 'lib/aws-sdk-wickr/types.rb', line 3413 class UpdateBotRequest < Struct.new( :network_id, :bot_id, :display_name, :group_id, :challenge, :suspend) SENSITIVE = [:challenge] include Aws::Structure end |
#network_id ⇒ String
The ID of the Wickr network containing the bot to update.
3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 |
# File 'lib/aws-sdk-wickr/types.rb', line 3413 class UpdateBotRequest < Struct.new( :network_id, :bot_id, :display_name, :group_id, :challenge, :suspend) SENSITIVE = [:challenge] include Aws::Structure end |
#suspend ⇒ Boolean
Set to true to suspend the bot or false to unsuspend it. Omit this field for standard updates that don’t affect suspension status.
3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 |
# File 'lib/aws-sdk-wickr/types.rb', line 3413 class UpdateBotRequest < Struct.new( :network_id, :bot_id, :display_name, :group_id, :challenge, :suspend) SENSITIVE = [:challenge] include Aws::Structure end |