Class: Aws::Wickr::Types::UpdateDataRetentionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::UpdateDataRetentionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A message indicating the result of the update operation.
Instance Attribute Details
#message ⇒ String
A message indicating the result of the update operation.
3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-wickr/types.rb', line 3461 class UpdateDataRetentionResponse < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |