Class: Aws::Wickr::Types::UpdateGuestUserResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::UpdateGuestUserResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A message indicating the result of the update operation.
Instance Attribute Details
#message ⇒ String
A message indicating the result of the update operation.
3438 3439 3440 3441 3442 |
# File 'lib/aws-sdk-wickr/types.rb', line 3438 class UpdateGuestUserResponse < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |