Class: Aws::Wickr::Types::UpdateNetworkRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique identifier for this request to ensure idempotency.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


3466
3467
3468
3469
3470
3471
3472
3473
# File 'lib/aws-sdk-wickr/types.rb', line 3466

class UpdateNetworkRequest < Struct.new(
  :network_id,
  :network_name,
  :client_token,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_key_arnString

The ARN of the Amazon Web Services KMS customer managed key to use for encrypting sensitive data in the network.

Returns:

  • (String)


3466
3467
3468
3469
3470
3471
3472
3473
# File 'lib/aws-sdk-wickr/types.rb', line 3466

class UpdateNetworkRequest < Struct.new(
  :network_id,
  :network_name,
  :client_token,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#network_idString

The ID of the Wickr network to update.

Returns:

  • (String)


3466
3467
3468
3469
3470
3471
3472
3473
# File 'lib/aws-sdk-wickr/types.rb', line 3466

class UpdateNetworkRequest < Struct.new(
  :network_id,
  :network_name,
  :client_token,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#network_nameString

The new name for the network. Must be between 1 and 20 characters.

Returns:

  • (String)


3466
3467
3468
3469
3470
3471
3472
3473
# File 'lib/aws-sdk-wickr/types.rb', line 3466

class UpdateNetworkRequest < Struct.new(
  :network_id,
  :network_name,
  :client_token,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end