Class: Aws::Wickr::Types::UpdateNetworkResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::UpdateNetworkResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A message indicating that the network was updated successfully.
Instance Attribute Details
#message ⇒ String
A message indicating that the network was updated successfully.
3481 3482 3483 3484 3485 |
# File 'lib/aws-sdk-wickr/types.rb', line 3481 class UpdateNetworkResponse < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |