Class: Aws::Wickr::Types::UpdateNetworkSettingsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::UpdateNetworkSettingsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#settings ⇒ Array<Types::Setting>
A list of the updated network settings, showing the new values for each modified setting.
Instance Attribute Details
#settings ⇒ Array<Types::Setting>
A list of the updated network settings, showing the new values for each modified setting.
3512 3513 3514 3515 3516 |
# File 'lib/aws-sdk-wickr/types.rb', line 3512 class UpdateNetworkSettingsResponse < Struct.new( :settings) SENSITIVE = [] include Aws::Structure end |