Class: Aws::Wickr::Types::UpdateSecurityGroupResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::UpdateSecurityGroupResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#security_group ⇒ Types::SecurityGroup
The updated security group details, including the new settings.
Instance Attribute Details
#security_group ⇒ Types::SecurityGroup
The updated security group details, including the new settings.
3612 3613 3614 3615 3616 |
# File 'lib/aws-sdk-wickr/types.rb', line 3612 class UpdateSecurityGroupResponse < Struct.new( :security_group) SENSITIVE = [] include Aws::Structure end |