Class: Aws::Wickr::Types::UpdateUserResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::UpdateUserResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:first_name, :last_name]
Instance Attribute Summary collapse
-
#code_validation ⇒ Boolean
Indicates whether the user can be verified through a custom invite code.
-
#first_name ⇒ String
The updated first name of the user.
-
#invite_code ⇒ String
The updated invite code for the user, if applicable.
-
#invite_expiration ⇒ Integer
The expiration time of the user’s invite code, specified in epoch seconds.
-
#last_name ⇒ String
The updated last name of the user.
-
#middle_name ⇒ String
The middle name of the user (currently not used).
-
#modified ⇒ Integer
The timestamp when the user was last modified, specified in epoch seconds.
-
#network_id ⇒ String
The ID of the network where the user was updated.
-
#security_group_ids ⇒ Array<String>
The list of security group IDs to which the user now belongs after the update.
-
#status ⇒ Integer
The user’s status after the update.
-
#suspended ⇒ Boolean
Indicates whether the user is suspended after the update.
-
#user_id ⇒ String
The unique identifier of the updated user.
Instance Attribute Details
#code_validation ⇒ Boolean
Indicates whether the user can be verified through a custom invite code.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 |
# File 'lib/aws-sdk-wickr/types.rb', line 3749 class UpdateUserResponse < Struct.new( :user_id, :network_id, :security_group_ids, :first_name, :last_name, :middle_name, :suspended, :modified, :status, :invite_code, :invite_expiration, :code_validation) SENSITIVE = [:first_name, :last_name] include Aws::Structure end |
#first_name ⇒ String
The updated first name of the user.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 |
# File 'lib/aws-sdk-wickr/types.rb', line 3749 class UpdateUserResponse < Struct.new( :user_id, :network_id, :security_group_ids, :first_name, :last_name, :middle_name, :suspended, :modified, :status, :invite_code, :invite_expiration, :code_validation) SENSITIVE = [:first_name, :last_name] include Aws::Structure end |
#invite_code ⇒ String
The updated invite code for the user, if applicable.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 |
# File 'lib/aws-sdk-wickr/types.rb', line 3749 class UpdateUserResponse < Struct.new( :user_id, :network_id, :security_group_ids, :first_name, :last_name, :middle_name, :suspended, :modified, :status, :invite_code, :invite_expiration, :code_validation) SENSITIVE = [:first_name, :last_name] include Aws::Structure end |
#invite_expiration ⇒ Integer
The expiration time of the user’s invite code, specified in epoch seconds.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 |
# File 'lib/aws-sdk-wickr/types.rb', line 3749 class UpdateUserResponse < Struct.new( :user_id, :network_id, :security_group_ids, :first_name, :last_name, :middle_name, :suspended, :modified, :status, :invite_code, :invite_expiration, :code_validation) SENSITIVE = [:first_name, :last_name] include Aws::Structure end |
#last_name ⇒ String
The updated last name of the user.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 |
# File 'lib/aws-sdk-wickr/types.rb', line 3749 class UpdateUserResponse < Struct.new( :user_id, :network_id, :security_group_ids, :first_name, :last_name, :middle_name, :suspended, :modified, :status, :invite_code, :invite_expiration, :code_validation) SENSITIVE = [:first_name, :last_name] include Aws::Structure end |
#middle_name ⇒ String
The middle name of the user (currently not used).
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 |
# File 'lib/aws-sdk-wickr/types.rb', line 3749 class UpdateUserResponse < Struct.new( :user_id, :network_id, :security_group_ids, :first_name, :last_name, :middle_name, :suspended, :modified, :status, :invite_code, :invite_expiration, :code_validation) SENSITIVE = [:first_name, :last_name] include Aws::Structure end |
#modified ⇒ Integer
The timestamp when the user was last modified, specified in epoch seconds.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 |
# File 'lib/aws-sdk-wickr/types.rb', line 3749 class UpdateUserResponse < Struct.new( :user_id, :network_id, :security_group_ids, :first_name, :last_name, :middle_name, :suspended, :modified, :status, :invite_code, :invite_expiration, :code_validation) SENSITIVE = [:first_name, :last_name] include Aws::Structure end |
#network_id ⇒ String
The ID of the network where the user was updated.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 |
# File 'lib/aws-sdk-wickr/types.rb', line 3749 class UpdateUserResponse < Struct.new( :user_id, :network_id, :security_group_ids, :first_name, :last_name, :middle_name, :suspended, :modified, :status, :invite_code, :invite_expiration, :code_validation) SENSITIVE = [:first_name, :last_name] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The list of security group IDs to which the user now belongs after the update.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 |
# File 'lib/aws-sdk-wickr/types.rb', line 3749 class UpdateUserResponse < Struct.new( :user_id, :network_id, :security_group_ids, :first_name, :last_name, :middle_name, :suspended, :modified, :status, :invite_code, :invite_expiration, :code_validation) SENSITIVE = [:first_name, :last_name] include Aws::Structure end |
#status ⇒ Integer
The user’s status after the update.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 |
# File 'lib/aws-sdk-wickr/types.rb', line 3749 class UpdateUserResponse < Struct.new( :user_id, :network_id, :security_group_ids, :first_name, :last_name, :middle_name, :suspended, :modified, :status, :invite_code, :invite_expiration, :code_validation) SENSITIVE = [:first_name, :last_name] include Aws::Structure end |
#suspended ⇒ Boolean
Indicates whether the user is suspended after the update.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 |
# File 'lib/aws-sdk-wickr/types.rb', line 3749 class UpdateUserResponse < Struct.new( :user_id, :network_id, :security_group_ids, :first_name, :last_name, :middle_name, :suspended, :modified, :status, :invite_code, :invite_expiration, :code_validation) SENSITIVE = [:first_name, :last_name] include Aws::Structure end |
#user_id ⇒ String
The unique identifier of the updated user.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 |
# File 'lib/aws-sdk-wickr/types.rb', line 3749 class UpdateUserResponse < Struct.new( :user_id, :network_id, :security_group_ids, :first_name, :last_name, :middle_name, :suspended, :modified, :status, :invite_code, :invite_expiration, :code_validation) SENSITIVE = [:first_name, :last_name] include Aws::Structure end |