Class: Aws::Wickr::Types::WickrAwsNetworks

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Identifies a Amazon Web Services Wickr network by region and network ID, used for configuring permitted networks for global federation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#network_idString

The network ID of the Wickr Amazon Web Services network.

Returns:

  • (String)


3868
3869
3870
3871
3872
3873
# File 'lib/aws-sdk-wickr/types.rb', line 3868

class WickrAwsNetworks < Struct.new(
  :region,
  :network_id)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services region identifier where the network is hosted (e.g., ‘us-east-1’).

Returns:

  • (String)


3868
3869
3870
3871
3872
3873
# File 'lib/aws-sdk-wickr/types.rb', line 3868

class WickrAwsNetworks < Struct.new(
  :region,
  :network_id)
  SENSITIVE = []
  include Aws::Structure
end