Class: Aws::Wickr::Types::BatchResetDevicesForUserRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::BatchResetDevicesForUserRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_ids ⇒ Array<String>
A list of application IDs identifying the specific devices to be reset for the user.
-
#client_token ⇒ String
A unique identifier for this request to ensure idempotency.
-
#network_id ⇒ String
The ID of the Wickr network containing the user whose devices will be reset.
-
#user_id ⇒ String
The ID of the user whose devices will be reset.
Instance Attribute Details
#app_ids ⇒ Array<String>
A list of application IDs identifying the specific devices to be reset for the user. Maximum 50 devices per batch request.
405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-wickr/types.rb', line 405 class BatchResetDevicesForUserRequest < Struct.new( :network_id, :user_id, :app_ids, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique identifier for this request to ensure idempotency.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-wickr/types.rb', line 405 class BatchResetDevicesForUserRequest < Struct.new( :network_id, :user_id, :app_ids, :client_token) SENSITIVE = [] include Aws::Structure end |
#network_id ⇒ String
The ID of the Wickr network containing the user whose devices will be reset.
405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-wickr/types.rb', line 405 class BatchResetDevicesForUserRequest < Struct.new( :network_id, :user_id, :app_ids, :client_token) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The ID of the user whose devices will be reset.
405 406 407 408 409 410 411 412 |
# File 'lib/aws-sdk-wickr/types.rb', line 405 class BatchResetDevicesForUserRequest < Struct.new( :network_id, :user_id, :app_ids, :client_token) SENSITIVE = [] include Aws::Structure end |