Class: Aws::Wickr::Types::BatchResetDevicesForUserResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::BatchResetDevicesForUserResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failed ⇒ Array<Types::BatchDeviceErrorResponseItem>
A list of device reset attempts that failed, including error details explaining why each device could not be reset.
-
#message ⇒ String
A message indicating the overall result of the batch device reset operation.
-
#successful ⇒ Array<Types::BatchDeviceSuccessResponseItem>
A list of application IDs that were successfully reset.
Instance Attribute Details
#failed ⇒ Array<Types::BatchDeviceErrorResponseItem>
A list of device reset attempts that failed, including error details explaining why each device could not be reset.
430 431 432 433 434 435 436 |
# File 'lib/aws-sdk-wickr/types.rb', line 430 class BatchResetDevicesForUserResponse < Struct.new( :message, :successful, :failed) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message indicating the overall result of the batch device reset operation.
430 431 432 433 434 435 436 |
# File 'lib/aws-sdk-wickr/types.rb', line 430 class BatchResetDevicesForUserResponse < Struct.new( :message, :successful, :failed) SENSITIVE = [] include Aws::Structure end |
#successful ⇒ Array<Types::BatchDeviceSuccessResponseItem>
A list of application IDs that were successfully reset.
430 431 432 433 434 435 436 |
# File 'lib/aws-sdk-wickr/types.rb', line 430 class BatchResetDevicesForUserResponse < Struct.new( :message, :successful, :failed) SENSITIVE = [] include Aws::Structure end |