Class: Aws::Wickr::Types::ConsentPopupConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::ConsentPopupConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Consent popup configuration displayed to users on login.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#close_button_label ⇒ String
Label for the close button on the consent popup.
-
#content ⇒ String
Body content of the consent popup in Markdown format.
-
#enabled ⇒ Boolean
Whether the consent popup is enabled.
-
#header ⇒ String
Header text displayed at the top of the consent popup.
Instance Attribute Details
#close_button_label ⇒ String
Label for the close button on the consent popup. Maximum 20 characters. Defaults to “Acknowledge” if not provided.
724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-wickr/types.rb', line 724 class ConsentPopupConfig < Struct.new( :enabled, :header, :content, :close_button_label) SENSITIVE = [] include Aws::Structure end |
#content ⇒ String
Body content of the consent popup in Markdown format. Maximum 5000 characters.
724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-wickr/types.rb', line 724 class ConsentPopupConfig < Struct.new( :enabled, :header, :content, :close_button_label) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
Whether the consent popup is enabled. When set to true, the popup is displayed to users on login.
724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-wickr/types.rb', line 724 class ConsentPopupConfig < Struct.new( :enabled, :header, :content, :close_button_label) SENSITIVE = [] include Aws::Structure end |
#header ⇒ String
Header text displayed at the top of the consent popup. Maximum 100 characters.
724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-wickr/types.rb', line 724 class ConsentPopupConfig < Struct.new( :enabled, :header, :content, :close_button_label) SENSITIVE = [] include Aws::Structure end |