Class: Aws::Wickr::Types::CreateNetworkRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_levelString

The access level for the network. Valid values are STANDARD or PREMIUM, which determine the features and capabilities available to network members.

Returns:

  • (String)


844
845
846
847
848
849
850
851
# File 'lib/aws-sdk-wickr/types.rb', line 844

class CreateNetworkRequest < Struct.new(
  :network_name,
  :access_level,
  :enable_premium_free_trial,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#enable_premium_free_trialBoolean

Specifies whether to enable a premium free trial for the network. It is optional and has a default value as false. When set to true, the network starts with premium features for a limited trial period.

Returns:

  • (Boolean)


844
845
846
847
848
849
850
851
# File 'lib/aws-sdk-wickr/types.rb', line 844

class CreateNetworkRequest < Struct.new(
  :network_name,
  :access_level,
  :enable_premium_free_trial,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_key_arnString

The ARN of the Amazon Web Services KMS customer managed key to use for encrypting sensitive data in the network.

Returns:

  • (String)


844
845
846
847
848
849
850
851
# File 'lib/aws-sdk-wickr/types.rb', line 844

class CreateNetworkRequest < Struct.new(
  :network_name,
  :access_level,
  :enable_premium_free_trial,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#network_nameString

The name for the new network. Must be between 1 and 20 characters.

Returns:

  • (String)


844
845
846
847
848
849
850
851
# File 'lib/aws-sdk-wickr/types.rb', line 844

class CreateNetworkRequest < Struct.new(
  :network_name,
  :access_level,
  :enable_premium_free_trial,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end