Class: Aws::Wickr::Types::CreateNetworkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::CreateNetworkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_level ⇒ String
The access level for the network.
-
#enable_premium_free_trial ⇒ Boolean
Specifies whether to enable a premium free trial for the network.
-
#encryption_key_arn ⇒ String
The ARN of the Amazon Web Services KMS customer managed key to use for encrypting sensitive data in the network.
-
#network_name ⇒ String
The name for the new network.
Instance Attribute Details
#access_level ⇒ String
The access level for the network. Valid values are STANDARD or PREMIUM, which determine the features and capabilities available to network members.
844 845 846 847 848 849 850 851 |
# File 'lib/aws-sdk-wickr/types.rb', line 844 class CreateNetworkRequest < Struct.new( :network_name, :access_level, :enable_premium_free_trial, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#enable_premium_free_trial ⇒ Boolean
Specifies whether to enable a premium free trial for the network. It is optional and has a default value as false. When set to true, the network starts with premium features for a limited trial period.
844 845 846 847 848 849 850 851 |
# File 'lib/aws-sdk-wickr/types.rb', line 844 class CreateNetworkRequest < Struct.new( :network_name, :access_level, :enable_premium_free_trial, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#encryption_key_arn ⇒ String
The ARN of the Amazon Web Services KMS customer managed key to use for encrypting sensitive data in the network.
844 845 846 847 848 849 850 851 |
# File 'lib/aws-sdk-wickr/types.rb', line 844 class CreateNetworkRequest < Struct.new( :network_name, :access_level, :enable_premium_free_trial, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#network_name ⇒ String
The name for the new network. Must be between 1 and 20 characters.
844 845 846 847 848 849 850 851 |
# File 'lib/aws-sdk-wickr/types.rb', line 844 class CreateNetworkRequest < Struct.new( :network_name, :access_level, :enable_premium_free_trial, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |