Class: Aws::Wickr::Types::CreateNetworkResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wickr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_key_arnString

The ARN of the KMS key being used to encrypt sensitive data in the network.

Returns:

  • (String)


868
869
870
871
872
873
874
# File 'lib/aws-sdk-wickr/types.rb', line 868

class CreateNetworkResponse < Struct.new(
  :network_id,
  :network_name,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#network_idString

The unique identifier assigned to the newly created network.

Returns:

  • (String)


868
869
870
871
872
873
874
# File 'lib/aws-sdk-wickr/types.rb', line 868

class CreateNetworkResponse < Struct.new(
  :network_id,
  :network_name,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#network_nameString

The name of the newly created network.

Returns:

  • (String)


868
869
870
871
872
873
874
# File 'lib/aws-sdk-wickr/types.rb', line 868

class CreateNetworkResponse < Struct.new(
  :network_id,
  :network_name,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end