Class: Aws::Wickr::Types::CreateNetworkResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::CreateNetworkResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encryption_key_arn ⇒ String
The ARN of the KMS key being used to encrypt sensitive data in the network.
-
#network_id ⇒ String
The unique identifier assigned to the newly created network.
-
#network_name ⇒ String
The name of the newly created network.
Instance Attribute Details
#encryption_key_arn ⇒ String
The ARN of the KMS key being used to encrypt sensitive data in the network.
868 869 870 871 872 873 874 |
# File 'lib/aws-sdk-wickr/types.rb', line 868 class CreateNetworkResponse < Struct.new( :network_id, :network_name, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#network_id ⇒ String
The unique identifier assigned to the newly created network.
868 869 870 871 872 873 874 |
# File 'lib/aws-sdk-wickr/types.rb', line 868 class CreateNetworkResponse < Struct.new( :network_id, :network_name, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#network_name ⇒ String
The name of the newly created network.
868 869 870 871 872 873 874 |
# File 'lib/aws-sdk-wickr/types.rb', line 868 class CreateNetworkResponse < Struct.new( :network_id, :network_name, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |