Class: Aws::Wickr::Types::DeleteNetworkResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::DeleteNetworkResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A message indicating that the network deletion has been initiated successfully.
Instance Attribute Details
#message ⇒ String
A message indicating that the network deletion has been initiated successfully.
1005 1006 1007 1008 1009 |
# File 'lib/aws-sdk-wickr/types.rb', line 1005 class DeleteNetworkResponse < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |