Class: Aws::Wickr::Types::ForbiddenError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::ForbiddenError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Access to the requested resource is forbidden. This error occurs when the authenticated user does not have the necessary permissions to perform the requested operation, even though they are authenticated.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A message explaining why access was denied and what permissions are required.
Instance Attribute Details
#message ⇒ String
A message explaining why access was denied and what permissions are required.
1117 1118 1119 1120 1121 |
# File 'lib/aws-sdk-wickr/types.rb', line 1117 class ForbiddenError < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |