Class: Aws::Wickr::Types::GetNetworkResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::GetNetworkResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_level ⇒ String
The access level of the network (STANDARD or PREMIUM), which determines available features and capabilities.
-
#aws_account_id ⇒ String
The Amazon Web Services account ID that owns the network.
-
#encryption_key_arn ⇒ String
The ARN of the Amazon Web Services KMS customer managed key used for encrypting sensitive data in the network.
-
#free_trial_expiration ⇒ String
The expiration date and time for the network’s free trial period, if applicable.
-
#migration_state ⇒ Integer
The SSO redirect URI migration state, managed by the SSO redirect migration wizard.
-
#network_arn ⇒ String
The Amazon Resource Name (ARN) of the network.
-
#network_id ⇒ String
The unique identifier of the network.
-
#network_name ⇒ String
The name of the network.
-
#standing ⇒ Integer
The current standing or status of the network.
Instance Attribute Details
#access_level ⇒ String
The access level of the network (STANDARD or PREMIUM), which determines available features and capabilities.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 |
# File 'lib/aws-sdk-wickr/types.rb', line 1332 class GetNetworkResponse < Struct.new( :network_id, :network_name, :access_level, :aws_account_id, :network_arn, :standing, :free_trial_expiration, :migration_state, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The Amazon Web Services account ID that owns the network.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 |
# File 'lib/aws-sdk-wickr/types.rb', line 1332 class GetNetworkResponse < Struct.new( :network_id, :network_name, :access_level, :aws_account_id, :network_arn, :standing, :free_trial_expiration, :migration_state, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#encryption_key_arn ⇒ String
The ARN of the Amazon Web Services KMS customer managed key used for encrypting sensitive data in the network.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 |
# File 'lib/aws-sdk-wickr/types.rb', line 1332 class GetNetworkResponse < Struct.new( :network_id, :network_name, :access_level, :aws_account_id, :network_arn, :standing, :free_trial_expiration, :migration_state, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#free_trial_expiration ⇒ String
The expiration date and time for the network’s free trial period, if applicable.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 |
# File 'lib/aws-sdk-wickr/types.rb', line 1332 class GetNetworkResponse < Struct.new( :network_id, :network_name, :access_level, :aws_account_id, :network_arn, :standing, :free_trial_expiration, :migration_state, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#migration_state ⇒ Integer
The SSO redirect URI migration state, managed by the SSO redirect migration wizard. Values: 0 (not started), 1 (in progress), or 2 (completed).
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 |
# File 'lib/aws-sdk-wickr/types.rb', line 1332 class GetNetworkResponse < Struct.new( :network_id, :network_name, :access_level, :aws_account_id, :network_arn, :standing, :free_trial_expiration, :migration_state, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#network_arn ⇒ String
The Amazon Resource Name (ARN) of the network.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 |
# File 'lib/aws-sdk-wickr/types.rb', line 1332 class GetNetworkResponse < Struct.new( :network_id, :network_name, :access_level, :aws_account_id, :network_arn, :standing, :free_trial_expiration, :migration_state, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#network_id ⇒ String
The unique identifier of the network.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 |
# File 'lib/aws-sdk-wickr/types.rb', line 1332 class GetNetworkResponse < Struct.new( :network_id, :network_name, :access_level, :aws_account_id, :network_arn, :standing, :free_trial_expiration, :migration_state, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#network_name ⇒ String
The name of the network.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 |
# File 'lib/aws-sdk-wickr/types.rb', line 1332 class GetNetworkResponse < Struct.new( :network_id, :network_name, :access_level, :aws_account_id, :network_arn, :standing, :free_trial_expiration, :migration_state, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#standing ⇒ Integer
The current standing or status of the network.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 |
# File 'lib/aws-sdk-wickr/types.rb', line 1332 class GetNetworkResponse < Struct.new( :network_id, :network_name, :access_level, :aws_account_id, :network_arn, :standing, :free_trial_expiration, :migration_state, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |