Class: Aws::Wickr::Types::InternalServerError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::InternalServerError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
An unexpected error occurred on the server while processing the request. This indicates a problem with the Wickr service itself rather than with the request. If this error persists, contact Amazon Web Services Support.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A message describing the internal server error that occurred.
Instance Attribute Details
#message ⇒ String
A message describing the internal server error that occurred.
1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-wickr/types.rb', line 1715 class InternalServerError < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |