Class: Aws::Wickr::Types::ListBlockedGuestUsersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::ListBlockedGuestUsersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#admin ⇒ String
Filter results to only include blocked guest users that were blocked by this administrator.
-
#max_results ⇒ Integer
The maximum number of blocked guest users to return in a single page.
-
#network_id ⇒ String
The ID of the Wickr network from which to list blocked guest users.
-
#next_token ⇒ String
The token for retrieving the next page of results.
-
#sort_direction ⇒ String
The direction to sort results.
-
#sort_fields ⇒ String
The field to sort blocked guest users by.
-
#username ⇒ String
Filter results to only include blocked guest users with usernames matching this value.
Instance Attribute Details
#admin ⇒ String
Filter results to only include blocked guest users that were blocked by this administrator.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 |
# File 'lib/aws-sdk-wickr/types.rb', line 1790 class ListBlockedGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :admin, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of blocked guest users to return in a single page. Valid range is 1-100. Default is 10.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 |
# File 'lib/aws-sdk-wickr/types.rb', line 1790 class ListBlockedGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :admin, :next_token) SENSITIVE = [] include Aws::Structure end |
#network_id ⇒ String
The ID of the Wickr network from which to list blocked guest users.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 |
# File 'lib/aws-sdk-wickr/types.rb', line 1790 class ListBlockedGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :admin, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for retrieving the next page of results. This is returned from a previous request when there are more results available.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 |
# File 'lib/aws-sdk-wickr/types.rb', line 1790 class ListBlockedGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :admin, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_direction ⇒ String
The direction to sort results. Valid values are 'ASC' (ascending) or 'DESC' (descending). Default is 'DESC'.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 |
# File 'lib/aws-sdk-wickr/types.rb', line 1790 class ListBlockedGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :admin, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_fields ⇒ String
The field to sort blocked guest users by. Accepted values include 'username', 'admin', and 'modified'.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 |
# File 'lib/aws-sdk-wickr/types.rb', line 1790 class ListBlockedGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :admin, :next_token) SENSITIVE = [] include Aws::Structure end |
#username ⇒ String
Filter results to only include blocked guest users with usernames matching this value.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 |
# File 'lib/aws-sdk-wickr/types.rb', line 1790 class ListBlockedGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :admin, :next_token) SENSITIVE = [] include Aws::Structure end |