Class: Aws::Wickr::Types::ListBotsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::ListBotsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
Filter results to only include bots with display names matching this value.
-
#group_id ⇒ String
Filter results to only include bots belonging to this security group.
-
#max_results ⇒ Integer
The maximum number of bots to return in a single page.
-
#network_id ⇒ String
The ID of the Wickr network from which to list bots.
-
#next_token ⇒ String
The token for retrieving the next page of results.
-
#sort_direction ⇒ String
The direction to sort results.
-
#sort_fields ⇒ String
The fields to sort bots by.
-
#status ⇒ Integer
Filter results to only include bots with this status (1 for pending, 2 for active).
-
#username ⇒ String
Filter results to only include bots with usernames matching this value.
Instance Attribute Details
#display_name ⇒ String
Filter results to only include bots with display names matching this value.
1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/aws-sdk-wickr/types.rb', line 1867 class ListBotsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction, :display_name, :username, :status, :group_id) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
Filter results to only include bots belonging to this security group.
1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/aws-sdk-wickr/types.rb', line 1867 class ListBotsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction, :display_name, :username, :status, :group_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of bots to return in a single page. Valid range is 1-100. Default is 10.
1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/aws-sdk-wickr/types.rb', line 1867 class ListBotsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction, :display_name, :username, :status, :group_id) SENSITIVE = [] include Aws::Structure end |
#network_id ⇒ String
The ID of the Wickr network from which to list bots.
1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/aws-sdk-wickr/types.rb', line 1867 class ListBotsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction, :display_name, :username, :status, :group_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for retrieving the next page of results. This is returned from a previous request when there are more results available.
1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/aws-sdk-wickr/types.rb', line 1867 class ListBotsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction, :display_name, :username, :status, :group_id) SENSITIVE = [] include Aws::Structure end |
#sort_direction ⇒ String
The direction to sort results. Valid values are 'ASC' (ascending) or 'DESC' (descending). Default is 'DESC'.
1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/aws-sdk-wickr/types.rb', line 1867 class ListBotsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction, :display_name, :username, :status, :group_id) SENSITIVE = [] include Aws::Structure end |
#sort_fields ⇒ String
The fields to sort bots by. Multiple fields can be specified by separating them with '+'. Accepted values include 'username', 'firstName', 'displayName', 'status', and 'groupId'.
1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/aws-sdk-wickr/types.rb', line 1867 class ListBotsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction, :display_name, :username, :status, :group_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
Filter results to only include bots with this status (1 for pending, 2 for active).
1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/aws-sdk-wickr/types.rb', line 1867 class ListBotsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction, :display_name, :username, :status, :group_id) SENSITIVE = [] include Aws::Structure end |
#username ⇒ String
Filter results to only include bots with usernames matching this value.
1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/aws-sdk-wickr/types.rb', line 1867 class ListBotsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction, :display_name, :username, :status, :group_id) SENSITIVE = [] include Aws::Structure end |