Class: Aws::Wickr::Types::ListGuestUsersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::ListGuestUsersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_period ⇒ String
Filter results to only include guest users from this billing period (e.g., '2024-01').
-
#max_results ⇒ Integer
The maximum number of guest users to return in a single page.
-
#network_id ⇒ String
The ID of the Wickr network from which to list guest users.
-
#next_token ⇒ String
The token for retrieving the next page of results.
-
#sort_direction ⇒ String
The direction to sort results.
-
#sort_fields ⇒ String
The field to sort guest users by.
-
#username ⇒ String
Filter results to only include guest users with usernames matching this value.
Instance Attribute Details
#billing_period ⇒ String
Filter results to only include guest users from this billing period (e.g., '2024-01').
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 |
# File 'lib/aws-sdk-wickr/types.rb', line 1997 class ListGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :billing_period, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of guest users to return in a single page. Valid range is 1-100. Default is 10.
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 |
# File 'lib/aws-sdk-wickr/types.rb', line 1997 class ListGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :billing_period, :next_token) SENSITIVE = [] include Aws::Structure end |
#network_id ⇒ String
The ID of the Wickr network from which to list guest users.
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 |
# File 'lib/aws-sdk-wickr/types.rb', line 1997 class ListGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :billing_period, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for retrieving the next page of results. This is returned from a previous request when there are more results available.
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 |
# File 'lib/aws-sdk-wickr/types.rb', line 1997 class ListGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :billing_period, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_direction ⇒ String
The direction to sort results. Valid values are 'ASC' (ascending) or 'DESC' (descending). Default is 'DESC'.
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 |
# File 'lib/aws-sdk-wickr/types.rb', line 1997 class ListGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :billing_period, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_fields ⇒ String
The field to sort guest users by. Accepted values include 'username' and 'billingPeriod'.
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 |
# File 'lib/aws-sdk-wickr/types.rb', line 1997 class ListGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :billing_period, :next_token) SENSITIVE = [] include Aws::Structure end |
#username ⇒ String
Filter results to only include guest users with usernames matching this value.
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 |
# File 'lib/aws-sdk-wickr/types.rb', line 1997 class ListGuestUsersRequest < Struct.new( :network_id, :max_results, :sort_direction, :sort_fields, :username, :billing_period, :next_token) SENSITIVE = [] include Aws::Structure end |