Class: Aws::Wickr::Types::ListSecurityGroupUsersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::ListSecurityGroupUsersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_id ⇒ String
The unique identifier of the security group whose users will be listed.
-
#max_results ⇒ Integer
The maximum number of users to return in a single page.
-
#network_id ⇒ String
The ID of the Wickr network containing the security group.
-
#next_token ⇒ String
The token for retrieving the next page of results.
-
#sort_direction ⇒ String
The direction to sort results.
-
#sort_fields ⇒ String
The field to sort users by.
Instance Attribute Details
#group_id ⇒ String
The unique identifier of the security group whose users will be listed.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-wickr/types.rb', line 2108 class ListSecurityGroupUsersRequest < Struct.new( :network_id, :group_id, :next_token, :max_results, :sort_fields, :sort_direction) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of users to return in a single page. Valid range is 1-100. Default is 10.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-wickr/types.rb', line 2108 class ListSecurityGroupUsersRequest < Struct.new( :network_id, :group_id, :next_token, :max_results, :sort_fields, :sort_direction) SENSITIVE = [] include Aws::Structure end |
#network_id ⇒ String
The ID of the Wickr network containing the security group.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-wickr/types.rb', line 2108 class ListSecurityGroupUsersRequest < Struct.new( :network_id, :group_id, :next_token, :max_results, :sort_fields, :sort_direction) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for retrieving the next page of results. This is returned from a previous request when there are more results available.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-wickr/types.rb', line 2108 class ListSecurityGroupUsersRequest < Struct.new( :network_id, :group_id, :next_token, :max_results, :sort_fields, :sort_direction) SENSITIVE = [] include Aws::Structure end |
#sort_direction ⇒ String
The direction to sort results. Valid values are 'ASC' (ascending) or 'DESC' (descending). Default is 'DESC'.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-wickr/types.rb', line 2108 class ListSecurityGroupUsersRequest < Struct.new( :network_id, :group_id, :next_token, :max_results, :sort_fields, :sort_direction) SENSITIVE = [] include Aws::Structure end |
#sort_fields ⇒ String
The field to sort users by. Multiple fields can be specified by separating them with '+'. Accepted values include 'username', 'firstName', and 'lastName'.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-wickr/types.rb', line 2108 class ListSecurityGroupUsersRequest < Struct.new( :network_id, :group_id, :next_token, :max_results, :sort_fields, :sort_direction) SENSITIVE = [] include Aws::Structure end |