Class: Aws::Wickr::Types::ListSecurityGroupUsersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::ListSecurityGroupUsersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use for retrieving the next page of results.
-
#users ⇒ Array<Types::User>
A list of user objects belonging to the security group within the current page.
Instance Attribute Details
#next_token ⇒ String
The token to use for retrieving the next page of results. If this is not present, there are no more results.
2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-wickr/types.rb', line 2131 class ListSecurityGroupUsersResponse < Struct.new( :users, :next_token) SENSITIVE = [] include Aws::Structure end |
#users ⇒ Array<Types::User>
A list of user objects belonging to the security group within the current page.
2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-wickr/types.rb', line 2131 class ListSecurityGroupUsersResponse < Struct.new( :users, :next_token) SENSITIVE = [] include Aws::Structure end |