Class: Aws::Wickr::Types::ListSecurityGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::ListSecurityGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of security groups to return in a single page.
-
#network_id ⇒ String
The ID of the Wickr network from which to list security groups.
-
#next_token ⇒ String
The token for retrieving the next page of results.
-
#sort_direction ⇒ String
The direction to sort results.
-
#sort_fields ⇒ String
The field to sort security groups by.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of security groups to return in a single page. Valid range is 1-100. Default is 10.
2164 2165 2166 2167 2168 2169 2170 2171 2172 |
# File 'lib/aws-sdk-wickr/types.rb', line 2164 class ListSecurityGroupsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction) SENSITIVE = [] include Aws::Structure end |
#network_id ⇒ String
The ID of the Wickr network from which to list security groups.
2164 2165 2166 2167 2168 2169 2170 2171 2172 |
# File 'lib/aws-sdk-wickr/types.rb', line 2164 class ListSecurityGroupsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for retrieving the next page of results. This is returned from a previous request when there are more results available.
2164 2165 2166 2167 2168 2169 2170 2171 2172 |
# File 'lib/aws-sdk-wickr/types.rb', line 2164 class ListSecurityGroupsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction) SENSITIVE = [] include Aws::Structure end |
#sort_direction ⇒ String
The direction to sort results. Valid values are 'ASC' (ascending) or 'DESC' (descending). Default is 'DESC'.
2164 2165 2166 2167 2168 2169 2170 2171 2172 |
# File 'lib/aws-sdk-wickr/types.rb', line 2164 class ListSecurityGroupsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction) SENSITIVE = [] include Aws::Structure end |
#sort_fields ⇒ String
The field to sort security groups by. Accepted values include 'id' and 'name'.
2164 2165 2166 2167 2168 2169 2170 2171 2172 |
# File 'lib/aws-sdk-wickr/types.rb', line 2164 class ListSecurityGroupsRequest < Struct.new( :network_id, :next_token, :max_results, :sort_fields, :sort_direction) SENSITIVE = [] include Aws::Structure end |