Class: Aws::Wickr::Types::ListUsersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::ListUsersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use for retrieving the next page of results.
-
#users ⇒ Array<Types::User>
A list of user objects matching the specified filters and within the current page.
Instance Attribute Details
#next_token ⇒ String
The token to use for retrieving the next page of results. If this is not present, there are no more results.
2271 2272 2273 2274 2275 2276 |
# File 'lib/aws-sdk-wickr/types.rb', line 2271 class ListUsersResponse < Struct.new( :next_token, :users) SENSITIVE = [] include Aws::Structure end |
#users ⇒ Array<Types::User>
A list of user objects matching the specified filters and within the current page.
2271 2272 2273 2274 2275 2276 |
# File 'lib/aws-sdk-wickr/types.rb', line 2271 class ListUsersResponse < Struct.new( :next_token, :users) SENSITIVE = [] include Aws::Structure end |