Class: Aws::Wickr::Types::ResourceNotFoundError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::ResourceNotFoundError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
The requested resource could not be found. This error occurs when you try to access or modify a network, user, bot, security group, or other resource that doesn’t exist or has been deleted.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A message identifying which resource was not found.
Instance Attribute Details
#message ⇒ String
A message identifying which resource was not found.
2913 2914 2915 2916 2917 |
# File 'lib/aws-sdk-wickr/types.rb', line 2913 class ResourceNotFoundError < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |