Class: Aws::Wickr::Types::ShredderSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::ShredderSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Configuration for the Wickr shredder feature, which writes random data over free memory and disk space on client devices. You can configure your Wickr shredder intensity using the parameters below.
<note markdown=“1”> Secure Shredder will not write over files that are permanently stored on the device or saved outside of the Wickr client. Wickr Network Administrators are able to disable file downloads within Security Group Settings.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#can_process_manually ⇒ Boolean
Specifies whether users can manually trigger the shredder to delete content.
-
#intensity ⇒ Integer
Controls the rate (MB/minute) at which the shredder function runs on clients.
Instance Attribute Details
#can_process_manually ⇒ Boolean
Specifies whether users can manually trigger the shredder to delete content.
3363 3364 3365 3366 3367 3368 |
# File 'lib/aws-sdk-wickr/types.rb', line 3363 class ShredderSettings < Struct.new( :can_process_manually, :intensity) SENSITIVE = [] include Aws::Structure end |
#intensity ⇒ Integer
Controls the rate (MB/minute) at which the shredder function runs on clients. Valid Values: Must be one of [0, 20, 60, 100].
<note markdown=“1”> A higher intensity setting could lead to higher battery usage on mobile devices.
</note>
3363 3364 3365 3366 3367 3368 |
# File 'lib/aws-sdk-wickr/types.rb', line 3363 class ShredderSettings < Struct.new( :can_process_manually, :intensity) SENSITIVE = [] include Aws::Structure end |