Class: Aws::Wickr::Types::UpdateNetworkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::UpdateNetworkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique identifier for this request to ensure idempotency.
-
#encryption_key_arn ⇒ String
The ARN of the Amazon Web Services KMS customer managed key to use for encrypting sensitive data in the network.
-
#network_id ⇒ String
The ID of the Wickr network to update.
-
#network_name ⇒ String
The new name for the network.
Instance Attribute Details
#client_token ⇒ String
A unique identifier for this request to ensure idempotency.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3466 3467 3468 3469 3470 3471 3472 3473 |
# File 'lib/aws-sdk-wickr/types.rb', line 3466 class UpdateNetworkRequest < Struct.new( :network_id, :network_name, :client_token, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#encryption_key_arn ⇒ String
The ARN of the Amazon Web Services KMS customer managed key to use for encrypting sensitive data in the network.
3466 3467 3468 3469 3470 3471 3472 3473 |
# File 'lib/aws-sdk-wickr/types.rb', line 3466 class UpdateNetworkRequest < Struct.new( :network_id, :network_name, :client_token, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#network_id ⇒ String
The ID of the Wickr network to update.
3466 3467 3468 3469 3470 3471 3472 3473 |
# File 'lib/aws-sdk-wickr/types.rb', line 3466 class UpdateNetworkRequest < Struct.new( :network_id, :network_name, :client_token, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#network_name ⇒ String
The new name for the network. Must be between 1 and 20 characters.
3466 3467 3468 3469 3470 3471 3472 3473 |
# File 'lib/aws-sdk-wickr/types.rb', line 3466 class UpdateNetworkRequest < Struct.new( :network_id, :network_name, :client_token, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |