Class: Aws::Wickr::Types::UpdateNetworkSettingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::UpdateNetworkSettingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_id ⇒ String
The ID of the Wickr network whose settings will be updated.
-
#settings ⇒ Types::NetworkSettings
A map of setting names to their new values.
Instance Attribute Details
#network_id ⇒ String
The ID of the Wickr network whose settings will be updated.
3498 3499 3500 3501 3502 3503 |
# File 'lib/aws-sdk-wickr/types.rb', line 3498 class UpdateNetworkSettingsRequest < Struct.new( :network_id, :settings) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Types::NetworkSettings
A map of setting names to their new values. Each setting should be provided with its appropriate type (boolean, string, number, etc.).
3498 3499 3500 3501 3502 3503 |
# File 'lib/aws-sdk-wickr/types.rb', line 3498 class UpdateNetworkSettingsRequest < Struct.new( :network_id, :settings) SENSITIVE = [] include Aws::Structure end |