Class: Aws::Wickr::Types::ValidationError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::ValidationError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
One or more fields in the request failed validation. This error provides detailed information about which fields were invalid and why, allowing you to correct the request and retry.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A message describing the validation error error that occurred.
-
#reasons ⇒ Array<Types::ErrorDetail>
A list of validation error details, where each item identifies a specific field that failed validation and explains the reason for the failure.
Instance Attribute Details
#message ⇒ String
A message describing the validation error error that occurred.
3847 3848 3849 3850 3851 3852 |
# File 'lib/aws-sdk-wickr/types.rb', line 3847 class ValidationError < Struct.new( :reasons, :message) SENSITIVE = [] include Aws::Structure end |
#reasons ⇒ Array<Types::ErrorDetail>
A list of validation error details, where each item identifies a specific field that failed validation and explains the reason for the failure.
3847 3848 3849 3850 3851 3852 |
# File 'lib/aws-sdk-wickr/types.rb', line 3847 class ValidationError < Struct.new( :reasons, :message) SENSITIVE = [] include Aws::Structure end |