Class: Aws::Wickr::Types::WickrAwsNetworks
- Inherits:
-
Struct
- Object
- Struct
- Aws::Wickr::Types::WickrAwsNetworks
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wickr/types.rb
Overview
Identifies a Amazon Web Services Wickr network by region and network ID, used for configuring permitted networks for global federation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_id ⇒ String
The network ID of the Wickr Amazon Web Services network.
-
#region ⇒ String
The Amazon Web Services region identifier where the network is hosted (e.g., ‘us-east-1’).
Instance Attribute Details
#network_id ⇒ String
The network ID of the Wickr Amazon Web Services network.
3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-wickr/types.rb', line 3868 class WickrAwsNetworks < Struct.new( :region, :network_id) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services region identifier where the network is hosted (e.g., ‘us-east-1’).
3868 3869 3870 3871 3872 3873 |
# File 'lib/aws-sdk-wickr/types.rb', line 3868 class WickrAwsNetworks < Struct.new( :region, :network_id) SENSITIVE = [] include Aws::Structure end |